#
# spec file for package perl-Test-Manifest
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Test-Manifest
Name:           perl-Test-Manifest
Version:        2.25.0
Release:        1.3
# 2.025 -> normalize -> 2.25.0
%define cpan_version 2.025
License:        Artistic-2.0
Summary:        Interact with a t/test_manifest file
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/B/BR/BRIANDFOY/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.64
BuildRequires:  perl(Test::More) >= 1
Provides:       perl(Test::Manifest) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
'Test::Harness' assumes that you want to run all of the _.t_ files in the
_t/_ directory in ASCII-betical order during 'make test' or './Build test'
unless you say otherwise. This leads to some interesting naming schemes for
test files to get them in the desired order. These interesting names ossify
when they get into source control, and get even more interesting as more
tests show up.

'Test::Manifest' overrides the default test file order. Instead of running
all of the _t/*.t_ files in ASCII-betical order, it looks in the
_t/test_manifest_ file to find out which tests you want to run and the
order in which you want to run them. It constructs the right value for the
build system to do the right thing.

In _t/test_manifest_, simply list the tests that you want to run. Their
order in the file is the order in which they run. You can comment lines
with a '#', just like in Perl, and 'Test::Manifest' will strip leading and
trailing whitespace from each line. It also checks that the specified file
is actually in the _t/_ directory. If the file does not exist, it does not
put its name in the list of test files to run and it will issue a warning.

Optionally, you can add a number after the test name in test_manifest to
define sets of tests. See 'get_t_files' for more information.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples SECURITY.md test_manifest test_manifest_levels test_manifest_with_include
%license LICENSE

%changelog
* Sun Jan  5 2025 Tina Müller <timueller+perl@suse.de>
- updated to 2.25.0 (2.025)
  see /usr/share/doc/packages/perl-Test-Manifest/Changes
  2.025 2025-01-04T15:58:23Z
  * refresh distro and move to BRIANDFOY
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Tue Jan  9 2024 Tina Müller <timueller+perl@suse.de>
- updated to 2.024
  see /usr/share/doc/packages/perl-Test-Manifest/Changes
  2.024 2024-01-08T15:34:49Z
  * refresh distro
  * fix tests for parallel execution (https://rt.cpan.org/Ticket/Display.html?id=92604)
* Sun Jan  9 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.023
  see /usr/share/doc/packages/perl-Test-Manifest/Changes
  2.023 2022-01-08T21:48:28Z
  * No code changes. Fix a link in the README.pod.
* Sun Jan 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.022
  see /usr/share/doc/packages/perl-Test-Manifest/Changes
  2.022 2021-01-16T13:29:49Z
  * freshen distro, remove Travis CI, add Github Actions
  * choroba fixed parallel testing (Github #4)
* Tue May  8 2018 coolo@suse.com
- updated to 2.021
  see /usr/share/doc/packages/perl-Test-Manifest/Changes
  2.021 2018-05-08T02:47:56Z
  * Clarify that it's the Artistic License 2.0
  2.02_01 2016-06-07T20:39:40Z
  * Start tracking down odd get_test_files failures.
* Tue Apr 14 2015 coolo@suse.com
- updated to 2.02
  see /usr/share/doc/packages/perl-Test-Manifest/Changes
  Changes for Test::Manifest
  2.02 - Tue Aug 26 13:01:43 2014
  Fix rt.cpan.org #98288: fix a spelling mistake
  2.00_001 - Thu Jul 11 20:22:40 2013
  * Switch back to Makefile.PL—so much simpler
  2.00_01 - Wed Jul 20 01:02:11 2011
  * Work with Module::Build by supplying a subclass.
  1.23 - Fri Jul 17 03:04:38 2009
  * Move everything to git and finally make a release
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Feb  2 2011 vcizek@novell.com
- bzipped source tarball
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Aug 27 2010 chris@computersalat.de
- update to 1.23
  * Fixed bug for missing file: previously the missing file
    name was passed through to run_t_files, although without
    the t/ added to its path. Test::Manifest should only
    warn about and skip missing files.
- 1.22_03 - Tue Jul 29 21:14:49 2008
  * Fixed bug for missing file: previously the missing file
    name was passed through to run_t_files, although without
    the t/ added to its path. Test::Manifest should only
    warn about and skip missing files.
- recreated by cpanspec 1.78
- noarch pkg
* Tue Aug 10 2010 anicka@suse.cz
- state license correctly (bnc#627747)
* Mon Aug  2 2010 anicka@suse.cz
- initial package
